@@ -22,10 +22,12 @@ except ImportError:
 __author__ = "Maximilian Schambach"
 
 from .core import get_artifact
+from .core import get_artifact_names
 from .core import get_conf_databases
 from .core import get_dataframe
 from .core import get_metric
 from .core import get_mongodb
+from .core import get_run_names
 from .core import get_uri
 from .core import resolve_artifacts
 from . import environ
