@@ -118,7 +118,7 @@ def get_client(conf_path: Union[Path, str],
 
 def get_mongodb(conf_path: Union[Path, str],
                 db_name: str = "sacred") -> Database:
-    """Get a MongoDB Database.
+    """Get a MongoDB Database instance.
 
     Args:
         conf_path: Path to MongoDB configuration file.
@@ -130,34 +130,42 @@ def get_mongodb(conf_path: Union[Path, str],
 
     """
     client = get_client(conf_path, db_name)
-    return client.get_database()
+    db = client.get_database()
+
+    if not ('metrics' in db.collection_names() and 'runs' in db.collection_names()):
+        raise UserWarning("No 'metrics' or 'runs' collection found in database. "
+                          "Are you sure this is a Sacred database?")
+
+    return db
 
 
-def get_metric(db: Database, id: int, metric: str) -> dict:
-    """Get metric from a Sacred experiment ID.
+def _wrap_ids(ids: Union[int, List[int], Tuple[int, ...]]) -> List[int]:
+    """Wrap input ids into list of ints.
 
     Args:
-        db: PyMongo Database instance.
-
-        id: Run ID of experiment.
-
-        metric: Name of the metric to get.
+        ids: Single or multiple ids.
 
     Returns:
-        dict, metric dictionary containing name, value, steps, etc.
+        List of ids.
     """
-    if type(db) != Database:
-        raise TypeError("db needs to be a PyMongo Database instance. "
-                        "Use mdbh.get_mongodb")
-
-    metrics = db.get_collection('metrics')
-    return metrics.find_one({"run_id": id, "name": metric})
+    return list(ids) if isinstance(ids, (tuple, list, set)) else [ids]
 
 
 def _get_dataframe_query(db: Database,
                          query: dict,
                          collection: Union[str, Collection]) -> pd.DataFrame:
-    """Get a DataFrame from a MongoDB query."""
+    """Get a DataFrame from a MongoDB query.
+    
+    Args:
+        db: Database instance to query.
+        
+        query: The query.
+        
+        collection: Collection to query.
+
+    Returns:
+        DataFrame of query result.
+    """
     if type(db) != Database:
         raise TypeError("db needs to be a PyMongo Database instance. "
                         "Use mdbh.get_mongodb")
@@ -168,6 +176,18 @@ def _get_dataframe_query(db: Database,
     return df
 
 
+def _get_run_ids(db: Database) -> List[int]:
+    """Get all run IDs of a database.
+
+    Args:
+        db: Database instance to query.
+
+    Returns:
+        List of run IDs of the database.
+    """
+    return _get_dataframe_query(db, {}, "runs")['_id'].tolist()
+
+
 def _get_dataframe(db: Database,
                    ids: Optional[Union[int, List[int], Tuple[int, ...]]] = None,
                    include_artifacts: bool = False) -> pd.DataFrame:
@@ -176,9 +196,10 @@ def _get_dataframe(db: Database,
     convenience.
 
     Args:
-        db: DataBase instance.
+        db: Database instance to query.
 
-        ids: Optional list of run IDs to get. If None, all IDs are queried.
+        ids: Optional run ID or list of IDs to get.
+             If None, all IDs are queried.
 
         include_artifacts: Whether to include a column for artifacts.
                            Artifacts can then be resolved via
@@ -196,9 +217,6 @@ def _get_dataframe(db: Database,
 
     query = {} if ids is None else {"_id": {"$in": ids}}
     df_runs = _get_dataframe_query(db, query, "runs")
-
-    # Set run_id (metrics), _id (runs) as index of DataFrames for later join
-    df_metric.index = df_metric['run_id'].tolist()
     df_runs.index = df_runs['_id'].tolist()
 
     # Extract config dict into columns
@@ -213,6 +231,27 @@ def _get_dataframe(db: Database,
     tmp.index = df_runs.index
     df_runs = pd.concat([df_runs, tmp], axis=1)
 
+    # Clean up DataFrame
+    df_m_del_cols = ['_id', ]
+    df_r_del_cols = ['experiment', 'format', 'command', 'start_time', 'meta',
+                     'resources', 'info', 'heartbeat',
+                     'result', 'stop_time', 'fail_trace', 'captured_out',
+                     'omniboard']
+
+    if not include_artifacts:
+        df_r_del_cols += ['artifacts']
+
+    for i in df_r_del_cols:
+        if i in df_runs.columns.tolist():
+            del df_runs[i]
+
+    # When there are no recorded metrics, just return runs dataframe
+    if len(df_metric) == 0:
+        return df_runs.rename(columns={'_id': 'id'})
+
+    # Set run_id (metrics), _id (runs) as index of DataFrames for later join
+    df_metric.index = df_metric['run_id'].tolist()
+
     # Get all IDs
     id_list = df_runs['_id'].unique().tolist()
 
@@ -237,24 +276,10 @@ def _get_dataframe(db: Database,
                 except TypeError or IndexError:
                     pass
 
-    # Clean up DataFrame
-    df_m_del_cols = ['_id', ]
-    df_r_del_cols = ['experiment', 'format', 'command', 'start_time', 'meta',
-                     'resources', 'info', 'heartbeat',
-                     'result', 'stop_time', 'fail_trace', 'captured_out',
-                     'omniboard']
-
-    if not include_artifacts:
-        df_r_del_cols += ['artifacts']
-
     for i in df_m_del_cols:
         if i in df_metrics_full.columns.tolist():
             del df_metrics_full[i]
 
-    for i in df_r_del_cols:
-        if i in df_runs.columns.tolist():
-            del df_runs[i]
-
     df = df_runs.join(df_metrics_full)
     df = df.rename(columns={'_id': 'id'})
 
@@ -266,7 +291,7 @@ def _get_dataframe_cached(db: Database,
                           include_artifacts: bool = False,
                           verify: bool = False,
                           force: bool = False) -> pd.DataFrame:
-    """Retrieve dataframe from MongoDB and cache result.
+    """Retrieve DataFrame from MongoDB and cache result locally.
 
     Caution: When retrieving the full database (using `ids = None`), by default
     it is not verified that the local version is up-to-date with the remote
@@ -274,9 +299,10 @@ def _get_dataframe_cached(db: Database,
     use `verify=True`.
 
     Args:
-        db: DataBase instance.
+        db: Database instance to query.
 
-        ids: Optional list of run IDs to get. If None, all IDs are queried.
+        ids: Optional run ID or list of IDs to get.
+             If None, all IDs are queried.
 
         include_artifacts: Whether to include a column for artifacts.
                            Artifacts can then be resolved via
@@ -285,7 +311,7 @@ def _get_dataframe_cached(db: Database,
         verify: Whether to verify that local version is up-to-date with remote
                 database. Only used when `ids=None`.
 
-        force: Whether to force re-loading from MongoDB, even if cached
+        force: Whether to force re-loading from MongoDB even if cached
                version is available.
 
     Returns:
@@ -301,7 +327,7 @@ def _get_dataframe_cached(db: Database,
     if ids is None and verify and not force:
         print("Verifying local version.")
         ids_local = df_local['id'].tolist()
-        ids_remote = _get_dataframe_query(db, {}, "runs")['_id'].tolist()
+        ids_remote = _get_run_ids(db)
         if ids_local != ids_remote:
             print("Remote version has been altered. Re-downloading.")
             path = caching.get(filename, get_data, force=True)
@@ -320,9 +346,9 @@ def get_dataframe(db: Database,
     convenience.
 
     Args:
-        db: DataBase instance.
+        db: Database instance to query.
 
-        ids: Optional list of run IDs to get. If None, all IDs are queried.
+        ids: Optional run ID or list of IDs to get. If None, all IDs are queried.
 
         include_artifacts: Whether to include a column for artifacts.
                            Artifacts can then be resolved via
@@ -343,11 +369,26 @@ def get_dataframe(db: Database,
         return _get_dataframe(db, ids, include_artifacts)
 
 
+def get_run_names(db: Database):
+    """Get a DataFrame containing only the run ID experiment names.
+
+    Args:
+        db:
+
+    Returns:
+        DataFrame with run IDs and experiment names.
+    """
+    df_runs = _get_dataframe_query(db, {}, "runs")
+    df_names = df_runs["experiment"].map(lambda x: x['name'])
+    df_names.index = df_runs['_id'].tolist()
+    return df_names
+
+
 def _get_artifact_content(db: Database, id: Union[str, ObjectId]) -> bytes:
     """Retrieves file content from GridFS by ObjectID. This corresponds to the way sacred saves artifacts.
 
     Args:
-        db: DataBase instance.
+        db: Database instance to query.
         id: Object id (in string or ObjectID format)
 
     Returns:
@@ -369,7 +410,7 @@ def resolve_artifacts(db: Database, df: pd.DataFrame) -> pd.DataFrame:
         df = mdbh.resolve_artifacts(db, df)
 
     Args:
-        db: DataBase instance.
+        db: Database instance.
         df: The Dataframe with 'artifacts' column.
 
     Returns:
@@ -398,22 +439,24 @@ def get_artifact_names(db: Database, id: int) -> List[str]:
 def get_artifact(db: Database,
                  id: int,
                  name: str,
-                 force: bool = False):
-    """Get path to artifact from database and run ID.
-    The artifacts are cached by default.
+                 force: bool = False) -> Path:
+    """Get path to artifact from a Database and run ID.
+    The artifacts are downloaded and cached by default.
 
     Args:
-        db: DataBase instance.
+        db: Database instance to query.
 
         id: Run ID to get artifact from.
 
         name: Name of artifact to get.
+              To obtain a list of available names, use
+              :func:`get_artifact_names()`
 
         force: Whether to force downloading of the artifact, even if cached
                version is available.
 
     Returns:
-
+        Path to the downloaded or cached artifact.
     """
     def get_data():
         """Download artifact from MongoDB."""
@@ -428,16 +471,25 @@ def get_artifact(db: Database,
         return _get_artifact_content(db, artifact['file_id'])
 
     filename = f"{db.name}_{id}_{name}"
-    return caching.get(filename, get_data)
+    return caching.get(filename, get_data, force)
 
 
-def _wrap_ids(ids: Union[int, List[int], Tuple[int, ...]]) -> List[int]:
-    """Wrap input ids into list of ints.
+def get_metric(db: Database, id: int, metric: str) -> dict:
+    """Get metric from a Sacred experiment ID.
 
     Args:
-        ids: Single or multiple ids.
+        db: PyMongo Database instance.
+
+        id: Run ID of experiment.
+
+        metric: Name of the metric to get.
 
     Returns:
-        List of ids.
+        dict, metric dictionary containing name, value, steps, etc.
     """
-    return list(ids) if isinstance(ids, (tuple, list, set)) else [ids]
+    if type(db) != Database:
+        raise TypeError("db needs to be a PyMongo Database instance. "
+                        "Use mdbh.get_mongodb")
+
+    metrics = db.get_collection('metrics')
+    return metrics.find_one({"run_id": id, "name": metric})
